@@ -56,7 +56,7 @@ from constructs import Construct
 SnsToLambda(self, 'test_sns_lambda',
             lambda_function_props=_lambda.FunctionProps(
                 code=_lambda.Code.from_asset('lambda'),
-                runtime=_lambda.Runtime.Python_3_11,
+                runtime=_lambda.Runtime.PYTHON_3_11,
                 handler='index.handler'
             )
             )
